@@ -1,5 +1,8 @@
 """Declares :class:`Signature`."""
+import typing
+
 from .joseheader import JOSEHeader
+from .jsonwebkeyset import JSONWebKeySet
 from .keychain import Keychain
 from .utils import b64decode
 
@@ -37,8 +40,11 @@ class Signature:
         self._signature = b64decode(signature)
         self._claims = claims
 
-    async def verify(self, keychain: Keychain, payload: bytes) -> bool:
-        return await keychain.verify(
+    async def verify(self,
+        verifier: typing.Union[Keychain, JSONWebKeySet],
+        payload: bytes
+    ) -> bool:
+        return await verifier.verify(
             signature=self._signature,
             payload=payload,
             algorithm=self.algorithm,
