@@ -45,21 +45,22 @@ class JSONWebKeySet:
     async def verify(self,
         signature: bytes,
         payload: bytes,
-        kid: str = None,
-        preset: str = None
+        algorithm: str = None,
+        using: str = None
     ) -> bool:
         """Verify `signature` using the JSON Web Key Set. The `kid`
         parameter specifies the key to use; if `kid` is ``None``, then
         try all keys.
         """
+        kid = using
         is_valid = False
         if kid is not None:
             if kid in self._index:
                 key = self._index[kid]
-                is_valid = await key.verify(signature, payload, preset=preset)
+                is_valid = await key.verify(signature, payload, preset=algorithm)
         else:
             for key in self._keys:
-                is_valid = await key.verify(signature, payload, preset=preset)
+                is_valid = await key.verify(signature, payload, preset=algorithm)
                 if is_valid:
                     break
         return is_valid
